import os
import unittest

from vsg.rules import architecture
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','architecture','architecture_test_input.vhd'))
oFileComment = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','architecture','architecture_comment_test_input.vhd'))
oFileIs = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'architecture_is_test_input.vhd'))

class testRuleArchitectureMethods(unittest.TestCase):

    def test_rule_001_exists(self):
        oRule = architecture.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '001')

    def test_rule_001(self):
        oRule = architecture.rule_001()

        dExpected = [9,20]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_002_exists(self):
        oRule = architecture.rule_002()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '002')

    def test_rule_002(self):
        oRule = architecture.rule_002()

        dExpected = [14]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_003_exists(self):
        oRule = architecture.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '003')

    def test_rule_003(self):
        oRule = architecture.rule_003()

        dExpected = [14]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004_exists(self):
        oRule = architecture.rule_004()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '004')

    def test_rule_004(self):
        oRule = architecture.rule_004()

        dExpected = [20]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005_exists(self):
        oRule = architecture.rule_005()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '005')

    def test_rule_005(self):
        oRule = architecture.rule_005()

        dExpected = [26]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006_exists(self):
        oRule = architecture.rule_006()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '006')

    def test_rule_006(self):
        oRule = architecture.rule_006()

        dExpected = [2,9]
        oRule.analyze(oFileIs)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007(self):
        oRule = architecture.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '007')
        dExpected = [22]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_008(self):
        oRule = architecture.rule_008()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '008')
        dExpected = [24,31]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_009(self):
        oRule = architecture.rule_009()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '009')
        dExpected = [7,13,24,31]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_010(self):
        oRule = architecture.rule_010()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '010')
        dExpected = [55,71]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_011(self):
        oRule = architecture.rule_011()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '011')
        dExpected = [24]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_012(self):
        oRule = architecture.rule_012()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '012')
        dExpected = [7,18]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_013(self):
        oRule = architecture.rule_013()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '013')
        dExpected = [3,20]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_014(self):
        oRule = architecture.rule_014()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '014')
        dExpected = [9,20]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_015(self):
        oRule = architecture.rule_015()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '015')
        dExpected = [26,33]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_016(self):
        oRule = architecture.rule_016()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '016')
        dExpected = [34]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_017(self):
        oRule = architecture.rule_017()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '017')
        dExpected = [34]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_018(self):
        oRule = architecture.rule_018()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '018')
        dExpected = [35]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_019(self):
        oRule = architecture.rule_019()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '019')
        dExpected = [20]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_020(self):
        oRule = architecture.rule_020()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '020')
        dExpected = [20,33]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_021(self):
        oRule = architecture.rule_021()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '021')
        dExpected = [29]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_022(self):
        oRule = architecture.rule_022()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '022')
        dExpected = [31]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_023(self):
        oRule = architecture.rule_023()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '023')
        dExpected = ['2-10']
        oRule.analyze(oFileComment)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_024(self):
        oRule = architecture.rule_024()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'architecture')
        self.assertEqual(oRule.identifier, '024')
        dExpected = [13,71]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)



import os
import unittest

from vsg.rules import case
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','case','case_test_input.vhd'))
oFileSequential = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','case','case_sequential_test_input.vhd'))
#oFileComment = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','case','case_comment_test_input.vhd'))

class testFixRuleCaseMethods(unittest.TestCase):

    def test_fix_rule_001(self):
        oRule = case.rule_001()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_002(self):
        oRule = case.rule_002()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_003(self):
        oRule = case.rule_003()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_004(self):
        oRule = case.rule_004()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_005(self):
        oRule = case.rule_005()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_006(self):
        oRule = case.rule_006()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_007(self):
        oRule = case.rule_007()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_008(self):
        oRule = case.rule_008()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_009(self):
        oRule = case.rule_009()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_010(self):
        oRule = case.rule_010()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_011(self):
        oRule = case.rule_011()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_012(self):
        oRule = case.rule_012()
        self.assertEqual(oFileSequential.lines[11].isSequential,False)
        self.assertEqual(oFileSequential.lines[11].indentLevel,3)
        dExpected = []
        oRule.fix(oFileSequential)
        oRule.analyze(oFileSequential)
        self.assertEqual(oRule.violations, dExpected)
        self.assertEqual(oFileSequential.lines[11].line,'      when 0 =>')
        self.assertEqual(oFileSequential.lines[11].indentLevel,3)
        self.assertEqual(oFileSequential.lines[12].line,' b <= \'0\';')
        self.assertEqual(oFileSequential.lines[12].indentLevel, oFileSequential.lines[11].indentLevel + 1)
        self.assertEqual(oFileSequential.lines[12].isSequential, True)
        self.assertEqual(oFileSequential.lines[12].insideCaseWhen, False)
        self.assertEqual(oFileSequential.lines[13].line,'      when 1 =>')

    def test_fix_rule_013(self):
        oRule = case.rule_013()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)




import os

import unittest

from vsg.rules import port
from vsg import vhdlFile


oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','port','port_test_input.vhd'))


class testRulePortMethods(unittest.TestCase):

    def test_rule_001(self):
        oRule = port.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '001')

        dExpected = [25,56]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_002(self):
        oRule = port.rule_002()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '002')

        dExpected = [39,56]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_003(self):
        oRule = port.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '003')

        dExpected = [25,56]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = port.rule_004()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '004')

        dExpected = [27,29,43,45,57,59,61]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = port.rule_005()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '005')

        dExpected = [29,40,42,60]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006(self):
        oRule = port.rule_006()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '006')

        dExpected = [27,30,44,58]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007(self):
        oRule = port.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '007')

        dExpected = [12,26,29,40,43,57,60,74]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_008(self):
        oRule = port.rule_008()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '008')

        dExpected = [13,30,41,44,61,75]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_009(self):
        oRule = port.rule_009()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '009')

        dExpected = [28,45,59,62]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_010(self):
        oRule = port.rule_010()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '010')

        dExpected = [12,13,14,26,27,28,40,41,42,60,61,62,74,75,76]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_011_prefix(self):
        oRule = port.rule_011()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '011')
        oRule.port_direction = 'Prefix'

        dExpected = [12,13,14,29,30,31,43,44,45,60,61,62,74,75,76,99,100,101,152]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_011_none(self):
        oRule = port.rule_011()
        oRule.port_direction = None

        dExpected = []
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_011_suffix(self):
        oRule = port.rule_011()
        oRule.port_direction = 'Suffix'

        dExpected = [9,10,11,12,13,14,26,27,28,29,30,31,40,41,42,43,44,45,57,58,59,60,61,62,71,72,73,74,75,76,87,88,89,119,120,121,129,130,131,141,142,152]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_012(self):
        oRule = port.rule_012()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '012')

        dExpected = [43,58,75]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_013(self):
        oRule = port.rule_013()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '013')

        dExpected = [119,121]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_014(self):
        oRule = port.rule_014()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '014')

        dExpected = [31,62]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_015(self):
        oRule = port.rule_015()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '015')

        dExpected = [46,77]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_016(self):
        oRule = port.rule_016()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '016')

        dExpected = [140]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_017(self):
        oRule = port.rule_017()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '017')

        dExpected = [25,39,98]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_018(self):
        oRule = port.rule_018()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '018')

        dExpected = [26,27,28,29,30,31,44]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_019(self):
        oRule = port.rule_019()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '019')

        dExpected = [40,43,44,45]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_020(self):
        oRule = port.rule_020()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '020')

        dExpected = [141]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_021(self):
        oRule = port.rule_021()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'port')
        self.assertEqual(oRule.identifier, '021')

        dExpected = [150]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)



import os

import unittest

from vsg.rules import for_loop
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','for_loop','for_loop_test_input.vhd'))

class testFixRuleForLoopMethods(unittest.TestCase):

    def test_fix_rule_001(self):
        oRule = for_loop.rule_001()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

#    def test_fix_rule_002(self):
#        oRule = for_loop.rule_002()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_003(self):
#        oRule = for_loop.rule_003()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_004(self):
#        oRule = for_loop.rule_004()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_005(self):
#        oRule = for_loop.rule_005()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_006(self):
#        oRule = for_loop.rule_006()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_006_case(self):
#        oRule = for_loop.rule_006()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFileCase)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_007(self):
#        oRule = for_loop.rule_007()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_008(self):
#        oRule = for_loop.rule_008()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_008_case(self):
#        oRule = for_loop.rule_008()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFileCase)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_009(self):
#        oRule = for_loop.rule_009()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_010(self):
#        oRule = for_loop.rule_010()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_010_case(self):
#        oRule = for_loop.rule_010()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFileCase)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_011(self):
#        oRule = for_loop.rule_011()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_011_case(self):
#        oRule = for_loop.rule_011()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFileCase)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_012(self):
#        oRule = for_loop.rule_012()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_013(self):
#        oRule = for_loop.rule_013()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_014(self):
#        oRule = for_loop.rule_014()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)




import unittest
from vsg import rule


class testRuleMethods(unittest.TestCase):

    def test_rule_exists(self):
        oRule = rule.rule()
        self.assertTrue(oRule)

    def test_rule_name(self):
        oRule = rule.rule()
        self.assertFalse(oRule.name)
        oRule.name = 'sName'
        self.assertEqual(oRule.name, 'sName')

    def test_rule_id(self):
        oRule = rule.rule()
        self.assertFalse(oRule.identifier)
        oRule.id = 'rule id 001'
        self.assertEqual(oRule.id, 'rule id 001')

    def test_rule_solution(self):
        oRule = rule.rule()
        self.assertFalse(oRule.solution)
        oRule.solution = 'rule solution'
        self.assertEqual(oRule.solution, 'rule solution')

    def test_add_violations_method(self):
        oRule = rule.rule()
        self.assertEqual(oRule.violations, [])
        oRule.add_violation(1)
        self.assertEqual(oRule.violations, [1])
        oRule.add_violation(10)
        oRule.add_violation(33)
        self.assertEqual(oRule.violations, [1,10,33])

    def test_rule_configure(self):
        oRule = rule.rule()
        oRule.name = 'xyz'
        oRule.identifier = '001'
        oRule.solution = 'This is my solution'
        self.assertEqual(oRule.name,'xyz')
        self.assertEqual(oRule.identifier,'001')
        self.assertEqual(oRule.solution,'This is my solution')
        self.assertEqual(oRule.disable,False)
        self.assertEqual(oRule.indentSize,2)

        dConfiguration = {}
        dConfiguration['rule'] = {}
        dConfiguration['rule']['xyz_001'] = {}
        dConfiguration['rule']['xyz_001']['disable'] = True

        oRule.configure(dConfiguration)

        self.assertEqual(oRule.disable,True)


        dConfiguration['rule']['xyz_002'] = {}
        dConfiguration['rule']['xyz_002']['disable'] = False

        oRule.configure(dConfiguration)

        self.assertEqual(oRule.disable,True)

        dConfiguration['rule']['xyz_001']['solution'] = 'This is the new solution'

        oRule.configure(dConfiguration)

        self.assertEqual(oRule.solution,'This is the new solution')

        dConfiguration['rule']['global'] = {}
        dConfiguration['rule']['global']['indentSize'] = 4

        oRule.configure(dConfiguration)

        self.assertEqual(oRule.indentSize,4)

        # Check for attributes that do not exist
        dConfiguration['rule']['xyz_001']['invalidAttribute'] = False
        oRule.configure(dConfiguration)
        self.assertEqual(oRule.disable,True)
        self.assertEqual(oRule.solution,'This is the new solution')
        self.assertEqual(oRule.indentSize,4)

    def test_report_violations(self):
        oRule = rule.rule()
        oRule.name = 'xyz'
        oRule.identifier = '001'
        oRule.solution = 'This is my solution'
        self.assertEqual(oRule.name,'xyz')
        self.assertEqual(oRule.identifier,'001')
        self.assertEqual(oRule.solution,'This is my solution')
        self.assertEqual(oRule.disable,False)
        self.assertEqual(oRule.indentSize,2)

        self.assertEqual(oRule.report_violations(1, True), 0)
        oRule.add_violation(1)
        self.assertEqual(oRule.report_violations(1, True), 1)



import os

import unittest

from vsg.rules import procedure
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'procedure_test_input.vhd'))


class testFixRuleProcedureMethods(unittest.TestCase):

    def test_fix_rule_001(self):
        oRule = procedure.rule_001()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)
        self.assertEqual(oFile.lines[14].line, '  procedure AVERAGE_SAMPLES;')
        self.assertEqual(oFile.lines[16].line, '  procedure AVERAGE_SAMPLES (')
        self.assertEqual(oFile.lines[40].line, '  procedure AVERAGE_SAMPLES is')

    def test_fix_rule_005(self):
        oRule = procedure.rule_005()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)
        self.assertEqual(oFile.lines[89].line, '    variable var_1 : integer;')
        self.assertEqual(oFile.lines[90].line, '    variable var_2 : integer;')




import os
import unittest

from vsg.rules import comment
from vsg import vhdlFile
from vsg import rule_list

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','comment','comment_test_input.vhd'))
oFileCase = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','comment','comment_case_test_input.vhd'))
oFileProcess = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','comment','comment_process_test_input.vhd'))
oFileLibrary = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'comment_library_test_input.vhd'))

class testRuleCommentMethods(unittest.TestCase):

    def test_rule_007(self):
        oRule = comment.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'comment')
        self.assertEqual(oRule.identifier, '007')
        dExpected = [3,7,12,13,17,19,21,23,27,30,45,49,64,68]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007_case(self):
        oRule = comment.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'comment')
        self.assertEqual(oRule.identifier, '007')
        dExpected = [23,24,25,29]
        oRule.analyze(oFileCase)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007_library(self):
        oRuleList = rule_list.rule_list(oFileLibrary)
        oRuleList.check_rules()
        iExpectedFailures = 1
        iFailures = 0
        for oRule in oRuleList.rules:
            iFailures += len(oRule.violations)
        self.assertEqual(iFailures, iExpectedFailures)

    def test_rule_003(self):
        oRule = comment.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'comment')
        self.assertEqual(oRule.identifier, '003')
        dExpected = ['26-33','39-46']
        oRule.analyze(oFileProcess)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = comment.rule_004()
        dExpected = [39]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = comment.rule_005()
        dExpected = [19,25,24,23]
        oRule.analyze(oFileCase)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006(self):
        oRule = comment.rule_006()
        dExpected = ['36-39']
        oRule.analyze(oFileProcess)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_001(self):
        oRule = comment.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'comment')
        self.assertEqual(oRule.identifier, '001')
        dExpected = [4]
        oRule.analyze(oFileLibrary)
        self.assertEqual(oRule.violations, dExpected)





import os

import unittest

from vsg.rules import package
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','package','package_test_input.vhd'))

class testFixRulePackageMethods(unittest.TestCase):

    def test_fix_rule_001(self):
        oRule = package.rule_001()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_002(self):
        oRule = package.rule_002()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_003(self):
        oRule = package.rule_003()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_004(self):
        oRule = package.rule_004()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_005(self):
        oRule = package.rule_005()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_006(self):
        oRule = package.rule_006()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_007(self):
        oRule = package.rule_007()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_008(self):
        oRule = package.rule_008()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_009(self):
        oRule = package.rule_009()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_010(self):
        oRule = package.rule_010()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_011(self):
        oRule = package.rule_011()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_012(self):
        oRule = package.rule_012()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_013(self):
        oRule = package.rule_013()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_014(self):
        oRule = package.rule_014()
        self.assertFalse(oRule.fixable)



import os

import unittest
from vsg import vhdlFile

oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','assert_statement','assert_test_input.vhd'))

class testVhdlFileMethods(unittest.TestCase):

    def test_isAssertKeyword_assignment(self):
        lExpected = [6,10,15,19]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isAssertKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isAssertEnd_assignment(self):
        lExpected = [8,12,17,21]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isAssertEnd:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insideAssert_assignment(self):
        lExpected = [6,7,8,10,11,12,15,16,17,19,20,21]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.insideAssert:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)




from vsg import rule
from vsg import fix

import re


class rule_005(rule.rule):
    '''
    Process rule 004 checks the "process" keyword is lower case.
    '''

    def __init__(self):
        rule.rule.__init__(self, 'process', '005')
        self.solution = 'Lowercase the "process" keyword.'
        self.phase = 6

    def analyze(self, oFile):
        for iLineNumber, oLine in enumerate(oFile.lines):
            if oLine.isProcessKeyword and not re.match('^\s*.*process', oLine.line):
                    self.add_violation(iLineNumber)

    def _fix_violations(self, oFile):
        for iLineNumber in self.violations:
            fix.lower_case(self, oFile.lines[iLineNumber], 'process')



import os
import unittest


from vsg import vhdlFile
from vsg import rule_list
from vsg.tests import utils

oBresenhamer = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'Bresenhamer.vhd'))
oDebouncer = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'Debouncer.vhd'))
oVgatop = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'VGA_Top.vhd'))
oPointer = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'Pointer.vhd'))
oFreqDiv = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'FreqDiv.vhd'))
oSynchronizer = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'Synchronizer.vhd'))
oFrameBuffer =  vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'FrameBuffer2.vhd'))

class testCodeExample(unittest.TestCase):

    def test_bresenhamer(self):
        oRuleList = rule_list.rule_list(oBresenhamer)
        oRuleList.fix(7)
        lExpected = ['']
        utils.read_file(os.path.join(os.path.dirname(__file__),'Bresenhamer.fixed.vhd'), lExpected)
        for iLineNumber, sLine in enumerate(lExpected):
            self.assertEqual(oBresenhamer.lines[iLineNumber].line, sLine)

    def test_debouncer(self):
        oRuleList = rule_list.rule_list(oDebouncer)
        oRuleList.fix(7)
        lExpected = ['']
        utils.read_file(os.path.join(os.path.dirname(__file__),'Debouncer.fixed.vhd'), lExpected)
        for iLineNumber, sLine in enumerate(lExpected):
            self.assertEqual(oDebouncer.lines[iLineNumber].line, sLine)

    def test_vga_top(self):
        oRuleList = rule_list.rule_list(oVgatop)
        oRuleList.fix(7)
        lExpected = ['']
        utils.read_file(os.path.join(os.path.dirname(__file__),'VGA_Top.fixed.vhd'), lExpected)
        for iLineNumber, sLine in enumerate(lExpected):
            self.assertEqual(oVgatop.lines[iLineNumber].line, sLine)

    def test_pointer(self):
        oRuleList = rule_list.rule_list(oPointer)
        oRuleList.fix(7)
        lExpected = ['']
        utils.read_file(os.path.join(os.path.dirname(__file__),'Pointer.fixed.vhd'), lExpected)
        for iLineNumber, sLine in enumerate(lExpected):
            self.assertEqual(oPointer.lines[iLineNumber].line, sLine)

    def test_freqdiv(self):
        oRuleList = rule_list.rule_list(oFreqDiv)
        oRuleList.fix(7)
        lExpected = ['']
        utils.read_file(os.path.join(os.path.dirname(__file__),'FreqDiv.fixed.vhd'), lExpected)
        for iLineNumber, sLine in enumerate(lExpected):
            self.assertEqual(oFreqDiv.lines[iLineNumber].line, sLine)

    def test_synchronizer(self):
        oRuleList = rule_list.rule_list(oSynchronizer)
        oRuleList.fix(7)
        lExpected = ['']
        utils.read_file(os.path.join(os.path.dirname(__file__),'Synchronizer.fixed.vhd'), lExpected)
        for iLineNumber, sLine in enumerate(lExpected):
            self.assertEqual(oSynchronizer.lines[iLineNumber].line, sLine)

    def test_framebuffer(self):
        oRuleList = rule_list.rule_list(oFrameBuffer)
        oRuleList.fix(7)
        lExpected = ['']
        utils.read_file(os.path.join(os.path.dirname(__file__),'FrameBuffer2.fixed.vhd'), lExpected)
        for iLineNumber, sLine in enumerate(lExpected):
            self.assertEqual(oFrameBuffer.lines[iLineNumber].line, sLine)



import os

import unittest
from vsg import vhdlFile

oFileConstant = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','constant','constant_test_input.vhd'))

class testVhdlFileConstantMethods(unittest.TestCase):

    def test_isConstant_assignment(self):
        lExpected = [5,6,7,8,9,10,19,21]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileConstant.lines):
            if oLine.isConstant:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isConstantEnd_assignment(self):
        lExpected = [5,6,7,8,9,11,19,27]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileConstant.lines):
            if oLine.isConstantEnd:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insideConstant_assignment(self):
        lExpected = [5,6,7,8,9,10,11,19,21,22,23,24,25,26,27]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileConstant.lines):
            if oLine.insideConstant:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)




from vsg import rule
from vsg import fix
from vsg import check

import re


class rule_014(rule.rule):
    '''
    Entity rule 014 checks the "entity" keyword is lower case in the closing of the entity.
    '''

    def __init__(self):
        rule.rule.__init__(self)
        self.name = 'entity'
        self.identifier = '014'
        self.solution = 'Change "entity" keyword to lower case.'
        self.phase = 6

    def analyze(self, oFile):
        for iLineNumber, oLine in enumerate(oFile.lines):
            if oLine.isEndEntityDeclaration and re.match('^\s*end\s+entity', oLine.line, re.IGNORECASE):
                lLine = oLine.line.split()
                check.is_lowercase(self, lLine[1], iLineNumber)

    def _fix_violations(self, oFile):
        for iLineNumber in self.violations:
            fix.lower_case(self, oFile.lines[iLineNumber], 'entity')



import os

import unittest

from vsg.rules import library
from vsg import vhdlFile


# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','library','library_test_input.vhd'))

class testRuleLibraryMethods(unittest.TestCase):

    def test_rule_001(self):
        oRule = library.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'library')
        self.assertEqual(oRule.identifier, '001')

        dExpected = [7,9,21]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_002(self):
        oRule = library.rule_002()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'library')
        self.assertEqual(oRule.identifier, '002')

        dExpected = [13,20,21]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_003(self):
        oRule = library.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'library')
        self.assertEqual(oRule.identifier, '003')

        dExpected = [21]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = library.rule_004()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'library')
        self.assertEqual(oRule.identifier, '004')

        dExpected = [9,20]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = library.rule_005()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'library')
        self.assertEqual(oRule.identifier, '005')

        dExpected = [26,27,30]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006(self):
        oRule = library.rule_006()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'library')
        self.assertEqual(oRule.identifier, '006')

        dExpected = [27,30]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007(self):
        oRule = library.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'library')
        self.assertEqual(oRule.identifier, '007')

        dExpected = [16,23,26,30]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_008(self):
        oRule = library.rule_008()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'library')
        self.assertEqual(oRule.identifier, '008')

        dExpected = [14,16,26,30]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)



import os

import unittest
from vsg import vhdlFile

oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','attribute','attribute_test_input.vhd'))

class testVhdlFileAttributeMethods(unittest.TestCase):

    def test_isAttributeKeyword_assignment(self):
        lExpected = [4,5,9,11]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isAttributeKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isAttributeEnd_assignment(self):
        lExpected = [4,6,9,12]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isAttributeEnd:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insideAttribute_assignment(self):
        lExpected = [4,5,6,9,11,12]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.insideAttribute:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)



import os
import unittest

from vsg.rules import component
from vsg import vhdlFile


oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'component_test_input.vhd'))
oFileComment = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'component_comment_test_input.vhd'))


class testFixRuleComponentMethods(unittest.TestCase):

    def test_fix_rule_001(self):
        oRule = component.rule_001()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_002(self):
        oRule = component.rule_002()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_003(self):
        oRule = component.rule_003()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_004(self):
        oRule = component.rule_004()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_005(self):
        oRule = component.rule_005()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_006(self):
        oRule = component.rule_006()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_007(self):
        oRule = component.rule_007()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_008(self):
        oRule = component.rule_008()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_009(self):
        oRule = component.rule_009()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_010(self):
        oRule = component.rule_010()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_011(self):
        oRule = component.rule_011()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_012(self):
        oRule = component.rule_012()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_013(self):
        oRule = component.rule_013()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_014(self):
        oRule = component.rule_014()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

#    def test_fix_rule_015(self):
#        oRule = component.rule_015()
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, [])

    def test_fix_rule_016(self):
        oRule = component.rule_016()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_017(self):
        oRule = component.rule_017()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_018(self):
        oRule = component.rule_018()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_019(self):
        oRule = component.rule_019()
        oRule.fix(oFileComment)
        oRule.analyze(oFileComment)
        self.assertEqual(oRule.violations, [])
        self.assertEqual(oFileComment.lines[7].line, '      generic_1 : std_logic := \'0\';')
        self.assertEqual(oFileComment.lines[12].line, '      port_2 : in    std_logic;')
        self.assertEqual(oFileComment.lines[14].line, '      port_4 : out   std_logic;')




import os

import unittest
from vsg import vhdlFile

oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','file_statement','file_test_input.vhd'))

class testVhdlFileFileMethods(unittest.TestCase):

    def test_isFileKeyword_assignment(self):
        lExpected = [4,6,9,11]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isFileKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isFileEnd_assignment(self):
        lExpected = [4,7,9,12]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isFileEnd:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insideFile_assignment(self):
        lExpected = [4,6,7,9,11,12]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.insideFile:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)



import os
import unittest

from vsg.rules import comment
from vsg import vhdlFile
from vsg import rule_list

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'comment_test_input.vhd'))
oFileCase = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'comment_case_test_input.vhd'))
oFileProcess = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'comment_process_test_input.vhd'))
oFileLibrary = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'comment_library_test_input.vhd'))


class testFixRuleCommentMethods(unittest.TestCase):

    def test_rule_007(self):
        oRule = comment.rule_007()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_rule_003(self):
        oRule = comment.rule_003()
        dExpected = []
        oRule.fix(oFileProcess)
        oRule.analyze(oFileProcess)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = comment.rule_004()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = comment.rule_005()
        dExpected = []
        oRule.fix(oFileCase)
        oRuleIndex = comment.rule_007()
        oRuleIndex.fix(oFileCase)
        oRule.analyze(oFileCase)
        self.assertEqual(oRule.violations, dExpected)
        self.assertEqual(oFileCase.lines[23].indentLevel, 3)
        self.assertEqual(oFileCase.lines[24].indentLevel, 3)
        self.assertEqual(oFileCase.lines[25].indentLevel, 3)

        self.assertEqual(oFileCase.lines[23].line, '      -- Comment 1')
        self.assertEqual(oFileCase.lines[24].line, '      -- Comment 2')
        self.assertEqual(oFileCase.lines[25].line, '      -- Comment 3')

    def test_rule_006(self):
        oRule = comment.rule_006()
        dExpected = []
        oRule.fix(oFileProcess)
        oRule.analyze(oFileProcess)
        self.assertEqual(oRule.violations, dExpected)
        self.assertEqual(oFileProcess.lines[37].line, '      variable a : integer 0 to 10;        -- comment')
        self.assertEqual(oFileProcess.lines[38].line, '      variable b : natural 0 to 256;       -- comment')

    def test_rule_001(self):
        oRuleList = rule_list.rule_list(oFileLibrary)
        oRuleList.fix(7)
        oRuleList.check_rules()

        self.assertEqual(oFileLibrary.lines[4].indentLevel, 1)
        self.assertEqual(oFileLibrary.lines[8].indentLevel, 1)

        self.assertEqual(oFileLibrary.lines[4].line, '  -- Comment 1')
        self.assertEqual(oFileLibrary.lines[8].line, '  -- Comment 1')

        oRuleList = rule_list.rule_list(oFileLibrary)
        oRuleList.check_rules()
        iExpectedFailures = 0
        iFailures = 0
        for oRule in oRuleList.rules:
            iFailures += len(oRule.violations)
        self.assertEqual(iFailures, iExpectedFailures)




import os

import unittest
import sys
sys.path.append('vsg')

from vsg.rules import type_definition
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'type_test_input.vhd'))


class testRuleTypeMethods(unittest.TestCase):

    def test_rule_001(self):
        oRule = type_definition.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '001')
        dExpected = [6,11]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_002(self):
        oRule = type_definition.rule_002()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '002')
        dExpected = [34]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_003(self):
        oRule = type_definition.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '003')
        dExpected = [29]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = type_definition.rule_004()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '004')
        dExpected = [27]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = type_definition.rule_005()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '005')
        dExpected = [32]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006(self):
        oRule = type_definition.rule_006()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '006')
        dExpected = [36]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007(self):
        oRule = type_definition.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '007')
        dExpected = [29]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_008(self):
        oRule = type_definition.rule_008()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '008')
        dExpected = [9,32]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_009(self):
        oRule = type_definition.rule_009()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '009')
        dExpected = [6,29]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_010(self):
        oRule = type_definition.rule_010()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '010')
        dExpected = [43]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_011(self):
        oRule = type_definition.rule_011()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '011')
        dExpected = [48]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_012(self):
        oRule = type_definition.rule_012()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'type')
        self.assertEqual(oRule.identifier, '012')
        dExpected = [60,61]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)




import os

import unittest
import sys
sys.path.append('vsg')

from vsg.rules import signal
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','signal','signal_test_input.vhd'))


class testFixRuleSignalMethods(unittest.TestCase):

    def test_fix_rule_001(self):
        oRule = signal.rule_001()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_002(self):
        oRule = signal.rule_002()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_003(self):
        oRule = signal.rule_003()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_004(self):
        oRule = signal.rule_004()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_005(self):
        oRule = signal.rule_005()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_006(self):
        oRule = signal.rule_006()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

#    def test_fix_rule_007(self):
#        oRule = signal.rule_007()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)

#    def test_fix_rule_008_with_no_prefixes(self):
#        oRule = signal.rule_008()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)
#
#    def test_fix_rule_008_with_prefixes(self):
#        oRule = signal.rule_008()
#        dExpected = []
#        oRule.fix(oFile)
#        oRule.prefixes = ['a_','b_','d_','e_']
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_009(self):
        oRule = signal.rule_009()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_010(self):
        oRule = signal.rule_010()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)




import unittest

from vsg import line

class testLineMethods(unittest.TestCase):

    def test_line_class_exists(self):
        oLine = line.line('contents of line')
        self.assertTrue(oLine)
        self.assertEqual(oLine.line, 'contents of line')

    def test_blank_line_attribute(self):
        oLine = line.line('contents of line')
        self.assertFalse(oLine.isBlank)
        oLine.isBlank = True
        self.assertTrue(oLine.isBlank)

    def test_library_attribute(self):
        oLine = line.line('contents of line')
        self.assertFalse(oLine.isLibrary)
        oLine.isLibrary = True
        self.assertTrue(oLine.isLibrary)

    def test_library_use_attribute(self):
        oLine = line.line('contents of line')
        self.assertFalse(oLine.isLibraryUse)
        oLine.isLibraryUse = True
        self.assertTrue(oLine.isLibraryUse)

    def test_isComment_attribute(self):
        oLine = line.line('contents of line')
        self.assertFalse(oLine.isComment)
        oLine.isComment = True
        self.assertTrue(oLine.isComment)

    def test_hasComment_attribute(self):
        oLine = line.line('contents of line')
        self.assertFalse(oLine.hasComment)
        oLine.hasComment = True
        self.assertTrue(oLine.hasComment)

    def test_hasInlineComment_attribute(self):
        oLine = line.line('contents of line')
        self.assertFalse(oLine.hasInlineComment)
        oLine.hasInlineComment = True
        self.assertTrue(oLine.hasInlineComment)

    def test_commentColumn_attribute(self):
        oLine = line.line('contents of line')
        self.assertEqual(oLine.commentColumn, None)
        oLine.commentColumn = 20
        self.assertEqual(oLine.commentColumn, 20)

    def test_line_lowering_attribute(self):
        oLine = line.line('ContenTs oF Line')
        self.assertEqual(oLine.lineLower, 'contents of line')

    def test_indentLevel_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.indentLevel, None)
        oLine.indentLevel = 10
        self.assertEqual(oLine.indentLevel, 10)

    def test_entity_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideEntity, False)
        oLine.insideEntity = True
        self.assertEqual(oLine.insideEntity, True)

    def test_inside_entity_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideEntity, False)
        oLine.insideEntity = True
        self.assertEqual(oLine.insideEntity, True)

    def test_entity_declaration_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isEntityDeclaration, False)
        oLine.isEntityDeclaration = True
        self.assertEqual(oLine.isEntityDeclaration, True)

    def test_end_entity_declaration_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isEndEntityDeclaration, False)
        oLine.isEndEntityDeclaration = True
        self.assertEqual(oLine.isEndEntityDeclaration, True)

    def test_inside_port_map_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insidePortMap, False)
        oLine.insidePortMap = True
        self.assertEqual(oLine.insidePortMap, True)

    def test_isPortDeclaration_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isPortDeclaration, False)
        oLine.isPortDeclaration = True
        self.assertEqual(oLine.isPortDeclaration, True)

    def test_isPortKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isPortKeyword, False)
        oLine.isPortKeyword = True
        self.assertEqual(oLine.isPortKeyword, True)

    def test_isEndPortMap_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isEndPortMap, False)
        oLine.isEndPortMap = True
        self.assertEqual(oLine.isEndPortMap, True)

    def test_inside_generic_map_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideGenericMap, False)
        oLine.insideGenericMap = True
        self.assertEqual(oLine.insideGenericMap, True)

    def test_generic_declaration_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isGenericDeclaration, False)
        oLine.isGenericDeclaration = True
        self.assertEqual(oLine.isGenericDeclaration, True)

    def test_isGenericKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isGenericKeyword, False)
        oLine.isGenericKeyword = True
        self.assertEqual(oLine.isGenericKeyword, True)

    def test_isEndGenericMap_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isEndGenericMap, False)
        oLine.isEndGenericMap = True
        self.assertEqual(oLine.isEndGenericMap, True)

    def test_inside_architecture_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideArchitecture, False)
        oLine.insideArchitecture = True
        self.assertEqual(oLine.insideArchitecture, True)

    def test_isArchitectureBegin_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isArchitectureBegin, False)
        oLine.isArchitectureBegin = True
        self.assertEqual(oLine.isArchitectureBegin, True)

    def test_isArchitectureKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isArchitectureKeyword, False)
        oLine.isArchitectureKeyword = True
        self.assertEqual(oLine.isArchitectureKeyword, True)

    def test_isEndArchitecture_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isEndArchitecture, False)
        oLine.isEndArchitecture = True
        self.assertEqual(oLine.isEndArchitecture, True)

    def test_isSignal_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isSignal, False)
        oLine.isSignal = True
        self.assertEqual(oLine.isSignal, True)

    def test_isConstant_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isConstant, False)
        oLine.isConstant = True
        self.assertEqual(oLine.isConstant, True)

    def test_insideConstant_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideConstant, False)
        oLine.insideConstant = True
        self.assertEqual(oLine.insideConstant, True)

    def test_isConstantEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isConstantEnd, False)
        oLine.isConstantEnd = True
        self.assertEqual(oLine.isConstantEnd, True)

    def test_insideProcess_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideProcess, False)
        oLine.insideProcess = True
        self.assertEqual(oLine.insideProcess, True)

    def test_isProcessBegin_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcessBegin, False)
        oLine.isProcessBegin = True
        self.assertEqual(oLine.isProcessBegin, True)

    def test_isProcessKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcessKeyword, False)
        oLine.isProcessKeyword = True
        self.assertEqual(oLine.isProcessKeyword, True)

    def test_isProcessLabel_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcessLabel, False)
        oLine.isProcessLabel = True
        self.assertEqual(oLine.isProcessLabel, True)

    def test_isEndProcess_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isEndProcess, False)
        oLine.isEndProcess = True
        self.assertEqual(oLine.isEndProcess, True)

    def test_isProcessDeclarative_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcessDeclarative, False)
        oLine.isProcessDeclarative = True
        self.assertEqual(oLine.isProcessDeclarative, True)

    def test_insideSensitivityList_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideSensitivityList, False)
        oLine.insideSensitivityList = True
        self.assertEqual(oLine.insideSensitivityList, True)

    def test_isSensitivityListBegin_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isSensitivityListBegin, False)
        oLine.isSensitivityListBegin = True
        self.assertEqual(oLine.isSensitivityListBegin, True)

    def test_isSensitivityListEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isSensitivityListEnd, False)
        oLine.isSensitivityListEnd = True
        self.assertEqual(oLine.isSensitivityListEnd, True)

    def test_insideConcurrent_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideConcurrent, False)
        oLine.insideConcurrent = True
        self.assertEqual(oLine.insideConcurrent, True)

    def test_isConcurrentBegin_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isConcurrentBegin, False)
        oLine.isConcurrentBegin = True
        self.assertEqual(oLine.isConcurrentBegin, True)

    def test_isEndConcurrent_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isEndConcurrent, False)
        oLine.isEndConcurrent = True
        self.assertEqual(oLine.isEndConcurrent, True)

    def test_insideIf_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideIf, False)
        oLine.insideIf= True
        self.assertEqual(oLine.insideIf, True)

    def test_isIfKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isIfKeyword, False)
        oLine.isIfKeyword = True
        self.assertEqual(oLine.isIfKeyword, True)

    def test_isThenKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isThenKeyword, False)
        oLine.isThenKeyword = True
        self.assertEqual(oLine.isThenKeyword, True)

    def test_isElseIfKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isElseIfKeyword, False)
        oLine.isElseIfKeyword = True
        self.assertEqual(oLine.isElseIfKeyword, True)

    def test_isEndIfKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isEndIfKeyword, False)
        oLine.isEndIfKeyword = True
        self.assertEqual(oLine.isEndIfKeyword, True)

    def test_isIfEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isIfEnd, False)
        oLine.isIfEnd = True
        self.assertEqual(oLine.isIfEnd, True)

    def test_isElseKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isElseKeyword, False)
        oLine.isElseKeyword = True
        self.assertEqual(oLine.isElseKeyword, True)

    def test_insideCase_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideCase, False)
        oLine.insideCase = True
        self.assertEqual(oLine.insideCase, True)

    def test_isCaseKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isCaseKeyword, False)
        oLine.isCaseKeyword = True
        self.assertEqual(oLine.isCaseKeyword, True)

    def test_isCaseWhenKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isCaseWhenKeyword, False)
        oLine.isCaseWhenKeyword = True
        self.assertEqual(oLine.isCaseWhenKeyword, True)

    def test_isCaseWhenEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isCaseWhenEnd, False)
        oLine.isCaseWhenEnd = True
        self.assertEqual(oLine.isCaseWhenEnd, True)

    def test_insideCaseWhen_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideCaseWhen, False)
        oLine.insideCaseWhen = True
        self.assertEqual(oLine.insideCaseWhen, True)

    def test_isEndCaseKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isEndCaseKeyword, False)
        oLine.isEndCaseKeyword = True
        self.assertEqual(oLine.isEndCaseKeyword, True)

    def test_isCaseIsKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isCaseIsKeyword, False)
        oLine.isCaseIsKeyword = True
        self.assertEqual(oLine.isCaseIsKeyword, True)

    def test_isCaseNull_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isCaseNull, False)
        oLine.isCaseNull = True
        self.assertEqual(oLine.isCaseNull, True)

    def test_insideSequential_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideSequential, False)
        oLine.insideSequential = True
        self.assertEqual(oLine.insideSequential, True)

    def test_isSequential_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isSequential, False)
        oLine.isSequential = True
        self.assertEqual(oLine.isSequential, True)

    def test_isSequentialEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isSequentialEnd, False)
        oLine.isSequentialEnd = True
        self.assertEqual(oLine.isSequentialEnd, True)

    def test_sequentialAlignmentColumn_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.sequentialAlignmentColumn, None)
        oLine.sequentialAlignmentColumn = 32
        self.assertEqual(oLine.sequentialAlignmentColumn, 32)

    def test_inside_component_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideComponent, False)
        oLine.insideComponent = True
        self.assertEqual(oLine.insideComponent, True)

    def test_component_declaration_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isComponentDeclaration, False)
        oLine.isComponentDeclaration = True
        self.assertEqual(oLine.isComponentDeclaration, True)

    def test_end_component_declaration_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isComponentEnd, False)
        oLine.isComponentEnd = True
        self.assertEqual(oLine.isComponentEnd, True)

    def test_inside_instantiation_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideInstantiation, False)
        oLine.insideInstantiation = True
        self.assertEqual(oLine.insideInstantiation, True)

    def test_instantiation_declaration_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isInstantiationDeclaration, False)
        oLine.isInstantiationDeclaration = True
        self.assertEqual(oLine.isInstantiationDeclaration, True)

    def test_Directinstantiation_declaration_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isDirectInstantiationDeclaration, False)
        oLine.isDirectInstantiationDeclaration = True
        self.assertEqual(oLine.isDirectInstantiationDeclaration, True)

    def test_inside_instantiation_port_map_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideInstantiationPortMap, False)
        oLine.insideInstantiationPortMap = True
        self.assertEqual(oLine.insideInstantiationPortMap, True)

    def test_instantiation_port_keyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isInstantiationPortKeyword, False)
        oLine.isInstantiationPortKeyword = True
        self.assertEqual(oLine.isInstantiationPortKeyword, True)

    def test_instantiation_port_end_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isInstantiationPortEnd, False)
        oLine.isInstantiationPortEnd= True
        self.assertEqual(oLine.isInstantiationPortEnd, True)

    def test_instantiation_port_assignment_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isInstantiationPortAssignment, False)
        oLine.isInstantiationPortAssignment= True
        self.assertEqual(oLine.isInstantiationPortAssignment, True)

    def test_inside_instantiation_generic_map_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideInstantiationGenericMap, False)
        oLine.insideInstantiationGenericMap = True
        self.assertEqual(oLine.insideInstantiationGenericMap, True)

    def test_instantiation_generic_keyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isInstantiationGenericKeyword, False)
        oLine.isInstantiationGenericKeyword = True
        self.assertEqual(oLine.isInstantiationGenericKeyword, True)

    def test_instantiation_generic_end_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isInstantiationGenericEnd, False)
        oLine.isInstantiationGenericEnd= True
        self.assertEqual(oLine.isInstantiationGenericEnd, True)

    def test_instantiation_generic_assignment_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isInstantiationGenericAssignment, False)
        oLine.isInstantiationGenericAssignment= True
        self.assertEqual(oLine.isInstantiationGenericAssignment, True)

    def test_inside_package_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insidePackage, False)
        oLine.insidePackage = True
        self.assertEqual(oLine.insidePackage, True)

    def test_isPackageKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isPackageKeyword, False)
        oLine.isPackageKeyword = True
        self.assertEqual(oLine.isPackageKeyword, True)

    def test_isPackageEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isPackageEnd, False)
        oLine.isPackageEnd = True
        self.assertEqual(oLine.isPackageEnd, True)

    def test_inside_packageBody_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insidePackageBody, False)
        oLine.insidePackageBody = True
        self.assertEqual(oLine.insidePackageBody, True)

    def test_isPackageBodyKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isPackageBodyKeyword, False)
        oLine.isPackageBodyKeyword = True
        self.assertEqual(oLine.isPackageBodyKeyword, True)

    def test_isPackageBodyEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isPackageBodyEnd, False)
        oLine.isPackageBodyEnd = True
        self.assertEqual(oLine.isPackageBodyEnd, True)

    def test_insideGenerate_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideGenerate, False)
        oLine.insideGenerate = True
        self.assertEqual(oLine.insideGenerate, True)

    def test_isGenerateBegin_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isGenerateBegin, False)
        oLine.isGenerateBegin = True
        self.assertEqual(oLine.isGenerateBegin, True)

    def test_isGenerateKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isGenerateKeyword, False)
        oLine.isGenerateKeyword = True
        self.assertEqual(oLine.isGenerateKeyword, True)

    def test_isGenerateEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isGenerateEnd, False)
        oLine.isGenerateEnd = True
        self.assertEqual(oLine.isGenerateEnd, True)

    def test_insideFunction_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideFunction, False)
        oLine.insideFunction = True
        self.assertEqual(oLine.insideFunction, True)

    def test_insideFunctionDeclarative_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideFunctionDeclarative, False)
        oLine.insideFunctionDeclarative = True
        self.assertEqual(oLine.insideFunctionDeclarative, True)

    def test_isFunctionParameter_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isFunctionParameter, False)
        oLine.isFunctionParameter = True
        self.assertEqual(oLine.isFunctionParameter, True)

    def test_isFunctionParameterEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isFunctionParameterEnd, False)
        oLine.isFunctionParameterEnd = True
        self.assertEqual(oLine.isFunctionParameterEnd, True)

    def test_isFunctionBegin_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isFunctionBegin, False)
        oLine.isFunctionBegin = True
        self.assertEqual(oLine.isFunctionBegin, True)

    def test_isFunctionKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isFunctionKeyword, False)
        oLine.isFunctionKeyword = True
        self.assertEqual(oLine.isFunctionKeyword, True)

    def test_isFunctionEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isFunctionEnd, False)
        oLine.isFunctionEnd = True
        self.assertEqual(oLine.isFunctionEnd, True)

    def test_isFunctionReturnKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isFunctionReturnKeyword, False)
        oLine.isFunctionReturnKeyword = True
        self.assertEqual(oLine.isFunctionReturnKeyword, True)

    def test_isFunctionReturn_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isFunctionReturn, False)
        oLine.isFunctionReturn = True
        self.assertEqual(oLine.isFunctionReturn, True)

    def test_isFunctionIs_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isFunctionIs, False)
        oLine.isFunctionIs= True
        self.assertEqual(oLine.isFunctionIs, True)

    def test_insideForLoop_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideForLoop, False)
        oLine.insideForLoop = True
        self.assertEqual(oLine.insideForLoop, True)

    def test_isForLoopKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isForLoopKeyword, False)
        oLine.isForLoopKeyword = True
        self.assertEqual(oLine.isForLoopKeyword, True)

    def test_isForLoopEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isForLoopEnd, False)
        oLine.isForLoopEnd = True
        self.assertEqual(oLine.isForLoopEnd, True)

    def test_insideWhileLoop_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideWhileLoop, False)
        oLine.insideWhileLoop = True
        self.assertEqual(oLine.insideWhileLoop, True)

    def test_isWhileLoopKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isWhileLoopKeyword, False)
        oLine.isWhileLoopKeyword = True
        self.assertEqual(oLine.isWhileLoopKeyword, True)

    def test_isWhileLoopEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isWhileLoopEnd, False)
        oLine.isWhileLoopEnd = True
        self.assertEqual(oLine.isWhileLoopEnd, True)

    def test_isTypeEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isTypeEnd, False)
        oLine.isTypeEnd = True
        self.assertEqual(oLine.isTypeEnd, True)

    def test_isTypeKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isTypeKeyword, False)
        oLine.isTypeKeyword = True
        self.assertEqual(oLine.isTypeKeyword, True)

    def test_isTypeEnumeratedEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isTypeEnumeratedEnd, False)
        oLine.isTypeEnumeratedEnd = True
        self.assertEqual(oLine.isTypeEnumeratedEnd, True)

    def test_isTypeEnumeratedKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isTypeEnumeratedKeyword, False)
        oLine.isTypeEnumeratedKeyword = True
        self.assertEqual(oLine.isTypeEnumeratedKeyword, True)

    def test_insideTypeEnumerated_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideTypeEnumerated, False)
        oLine.insideTypeEnumerated = True
        self.assertEqual(oLine.insideTypeEnumerated, True)

    def test_isSubtypeEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isSubtypeEnd, False)
        oLine.isSubtypeEnd = True
        self.assertEqual(oLine.isSubtypeEnd, True)

    def test_isSubtypeKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isSubtypeKeyword, False)
        oLine.isSubtypeKeyword = True
        self.assertEqual(oLine.isSubtypeKeyword, True)

    def test_insideSubtype_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideSubtype, False)
        oLine.insideSubtype= True
        self.assertEqual(oLine.insideSubtype, True)

    def test_isTypeArrayEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isTypeArrayEnd, False)
        oLine.isTypeArrayEnd = True
        self.assertEqual(oLine.isTypeArrayEnd, True)

    def test_isTypeArrayKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isTypeArrayKeyword, False)
        oLine.isTypeArrayKeyword = True
        self.assertEqual(oLine.isTypeArrayKeyword, True)

    def test_insideTypeArray_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideTypeArray, False)
        oLine.insideTypeArray= True
        self.assertEqual(oLine.insideTypeArray, True)

    def test_isTypeRecordEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isTypeRecordEnd, False)
        oLine.isTypeRecordEnd = True
        self.assertEqual(oLine.isTypeRecordEnd, True)

    def test_isTypeRecordKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isTypeRecordKeyword, False)
        oLine.isTypeRecordKeyword = True
        self.assertEqual(oLine.isTypeRecordKeyword, True)

    def test_insideTypeRecord_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideTypeRecord, False)
        oLine.insideTypeRecord= True
        self.assertEqual(oLine.insideTypeRecord, True)

    def test_isVariable_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isVariable, False)
        oLine.isVariable = True
        self.assertEqual(oLine.isVariable, True)

    def test_insideVariableAssignment_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideVariableAssignment, False)
        oLine.insideVariableAssignment = True
        self.assertEqual(oLine.insideVariableAssignment, True)

    def test_isVariableAssignment_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isVariableAssignment, False)
        oLine.isVariableAssignment = True
        self.assertEqual(oLine.isVariableAssignment, True)

    def test_isVariableAssignmentEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isVariableAssignmentEnd, False)
        oLine.isVariableAssignmentEnd = True
        self.assertEqual(oLine.isVariableAssignmentEnd, True)

    def test_variableAssignmentAlignmentColumn_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.variableAssignmentAlignmentColumn, None)
        oLine.variableAssignmentAlignmentColumn = 32
        self.assertEqual(oLine.variableAssignmentAlignmentColumn, 32)

    def test_isAssertKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.isAssertKeyword)
        oLine.isAssertKeyword = True
        self.assertTrue(oLine.isAssertKeyword)

    def test_isAssertEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.isAssertEnd)
        oLine.isAssertEnd = True
        self.assertTrue(oLine.isAssertEnd)

    def test_insideAssert_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.insideAssert)
        oLine.insideAssert = True
        self.assertTrue(oLine.insideAssert)

    def test_isWithKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.isWithKeyword)
        oLine.isWithKeyword = True
        self.assertTrue(oLine.isWithKeyword)

    def test_isAttributeKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.isAttributeKeyword)
        oLine.isAttributeKeyword = True
        self.assertTrue(oLine.isAttributeKeyword)

    def test_isAttributeEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.isAttributeEnd)
        oLine.isAttributeEnd = True
        self.assertTrue(oLine.isAttributeEnd)

    def test_insideAttribute_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.insideAttribute)
        oLine.insideAttribute = True
        self.assertTrue(oLine.insideAttribute)

    def test_isFileKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.isFileKeyword)
        oLine.isFileKeyword = True
        self.assertTrue(oLine.isFileKeyword)

    def test_isFileEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.isFileEnd)
        oLine.isFileEnd = True
        self.assertTrue(oLine.isFileEnd)

    def test_insideFile_attribute(self):
        oLine = line.line('contents of Line')
        self.assertFalse(oLine.insideFile)
        oLine.insideFile = True
        self.assertTrue(oLine.insideFile)

    def test_insideProcedure_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideProcedure, False)
        oLine.insideProcedure = True
        self.assertEqual(oLine.insideProcedure, True)

    def test_insideProcedureDeclarative_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.insideProcedureDeclarative, False)
        oLine.insideProcedureDeclarative = True
        self.assertEqual(oLine.insideProcedureDeclarative, True)

    def test_isProcedureParameter_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcedureParameter, False)
        oLine.isProcedureParameter = True
        self.assertEqual(oLine.isProcedureParameter, True)

    def test_isProcedureParameterEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcedureParameterEnd, False)
        oLine.isProcedureParameterEnd = True
        self.assertEqual(oLine.isProcedureParameterEnd, True)

    def test_isProcedureBegin_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcedureBegin, False)
        oLine.isProcedureBegin = True
        self.assertEqual(oLine.isProcedureBegin, True)

    def test_isProcedureKeyword_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcedureKeyword, False)
        oLine.isProcedureKeyword = True
        self.assertEqual(oLine.isProcedureKeyword, True)

    def test_isProcedureEnd_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcedureEnd, False)
        oLine.isProcedureEnd = True
        self.assertEqual(oLine.isProcedureEnd, True)

    def test_isProcedureReturn_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcedureReturn, False)
        oLine.isProcedureReturn = True
        self.assertEqual(oLine.isProcedureReturn, True)

    def test_isProcedureIs_attribute(self):
        oLine = line.line('contents of Line')
        self.assertEqual(oLine.isProcedureIs, False)
        oLine.isProcedureIs = True
        self.assertEqual(oLine.isProcedureIs, True)



import os

import unittest

from vsg.rules import function
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'function_test_input.vhd'))
oFileMultiple = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'function_multiple_parameters_test_input.vhd'))


class testRuleFunctionMethods(unittest.TestCase):

    def test_rule_001(self):
        oRule = function.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'function')
        self.assertEqual(oRule.identifier, '001')
        dExpected = [16,17,18,19,21,22,23,24]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_002(self):
        oRule = function.rule_002()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'function')
        self.assertEqual(oRule.identifier, '002')
        dExpected = [16]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_003(self):
        oRule = function.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'function')
        self.assertEqual(oRule.identifier, '003')
        dExpected = [28]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = function.rule_004()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'function')
        self.assertEqual(oRule.identifier, '004')
        dExpected = [31]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = function.rule_005()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'function')
        self.assertEqual(oRule.identifier, '005')
        dExpected = [36]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006(self):
        oRule = function.rule_006()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'function')
        self.assertEqual(oRule.identifier, '006')
        dExpected = [21]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007(self):
        oRule = function.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'function')
        self.assertEqual(oRule.identifier, '007')
        dExpected = [19,24]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_008(self):
        oRule = function.rule_008()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'function')
        self.assertEqual(oRule.identifier, '008')
        dExpected = [5,6,7]
        oRule.analyze(oFileMultiple)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_009(self):
        oRule = function.rule_009()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'function')
        self.assertEqual(oRule.identifier, '009')
        dExpected = [4]
        oRule.analyze(oFileMultiple)
        self.assertEqual(oRule.violations, dExpected)



import os

import unittest

from vsg.rules import generic
from vsg import vhdlFile


oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'generic_test_input.vhd'))
oFileMultiple = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'generic_multiple_on_one_line_test_input.vhd'))
oFileComponent = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'generic_component_test_input.vhd'))

class testRuleGenericMethods(unittest.TestCase):


    def test_rule_001(self):
        oRule = generic.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '001')

        dExpected = [82]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_002(self):
        oRule = generic.rule_002()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '002')

        dExpected = [51,66]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_003(self):
        oRule = generic.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '003')

        dExpected = [51,82]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = generic.rule_004()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '004')

        dExpected = [21,53,68,83]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = generic.rule_005()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '005')

        dExpected = [36,37,52,67,84]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006(self):
        oRule = generic.rule_006()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '006')

        dExpected = [37,52,53,68,83]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_component_rule_006(self):
        oRule = generic.rule_006()

        dExpected = [36,37]
        oRule.analyze(oFileComponent)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007(self):
        oRule = generic.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '007')

        dExpected = [22,36,37,67]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_008(self):
        oRule = generic.rule_008()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '008')

        dExpected = [85,117]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_009(self):
        oRule = generic.rule_009()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '009')

        dExpected = [66,82,95]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_010(self):
        oRule = generic.rule_010()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '010')

        dExpected = [97]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

#    def test_rule_011(self):
#        oRule = generic.rule_011()
#        self.assertTrue(oRule)
#        self.assertEqual(oRule.name, 'generic')
#        self.assertEqual(oRule.identifier, '011')
#
#        dExpected = [67,96,116]
#        oRule.analyze(oFile)
#        self.assertEqual(oRule.violations, dExpected)

    def test_rule_012(self):
        oRule = generic.rule_012()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '012')

        dExpected = ['20-23','51-54','66-69','82-85']
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_013(self):
        oRule = generic.rule_013()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '013')

        dExpected = [139]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_014(self):
        oRule = generic.rule_014()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '014')

        dExpected = [68,116]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_015(self):
        oRule = generic.rule_015()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '015')

        dExpected = ['20-23','51-54','66-69']
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_016(self):
        oRule = generic.rule_016()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '016')

        dExpected = [21]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

        oRule.violations = []
        dExpected = [5]
        oRule.analyze(oFileMultiple)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_017(self):
        oRule = generic.rule_017()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'generic')
        self.assertEqual(oRule.identifier, '017')

        dExpected = [52,96]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)




import os
import unittest

from vsg.rules import generate
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','generate','generate_test_input.vhd'))

class testFixRuleGenerateMethods(unittest.TestCase):

    def test_fix_rule_001(self):
        oRule = generate.rule_001()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_002(self):
        oRule = generate.rule_002()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_003(self):
        oRule = generate.rule_003()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_004(self):
        oRule = generate.rule_004()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])

    def test_fix_rule_005(self):
        oRule = generate.rule_005()
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, [])



import os

import unittest
import sys
sys.path.append('vsg')

from vsg.rules import variable
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','variable','variable_test_input.vhd'))

class testRuleVariableMethods(unittest.TestCase):

    def test_rule_001(self):
        oRule = variable.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'variable')
        self.assertEqual(oRule.identifier, '001')
        dExpected = [6,8,15]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_002(self):
        oRule = variable.rule_002()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'variable')
        self.assertEqual(oRule.identifier, '002')
        dExpected = [7,11,13]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_003(self):
        oRule = variable.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'variable')
        self.assertEqual(oRule.identifier, '003')
        dExpected = [8,9,12]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = variable.rule_004()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'variable')
        self.assertEqual(oRule.identifier, '004')
        dExpected = [6,9,12,15]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = variable.rule_005()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'variable')
        self.assertEqual(oRule.identifier, '005')
        dExpected = [6,10,13,14,16,20,21]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006(self):
        oRule = variable.rule_006()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'variable')
        self.assertEqual(oRule.identifier, '006')
        dExpected = [7,11,19,21]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007(self):
        oRule = variable.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'variable')
        self.assertEqual(oRule.identifier, '007')
        dExpected = [11,16]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_009(self):
        oRule = variable.rule_009()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'variable')
        self.assertEqual(oRule.identifier, '009')
        dExpected = ['3-25']
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_010(self):
        oRule = variable.rule_010()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'variable')
        self.assertEqual(oRule.identifier, '010')
        dExpected = [12,18]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)



import os
import unittest

from vsg.rules import sequential
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','sequential','sequential_test_input.vhd'))

class testRuleSequentialMethods(unittest.TestCase):

    def test_rule_001(self):
        oRule = sequential.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'sequential')
        self.assertEqual(oRule.identifier, '001')
        dExpected = [14,20,28,56,66,73,81,89,90]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_002(self):
        oRule = sequential.rule_002()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'sequential')
        self.assertEqual(oRule.identifier, '002')
        dExpected = [26,33,65,83]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_003(self):
        oRule = sequential.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'sequential')
        self.assertEqual(oRule.identifier, '003')
        dExpected = [38,40,81,89]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = sequential.rule_004()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'sequential')
        self.assertEqual(oRule.identifier, '004')
        dExpected = [54,55,74]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = sequential.rule_005()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'sequential')
        self.assertEqual(oRule.identifier, '005')
        dExpected = ['13-15','20-22', '26-28','38-40','53-58','65-66','73-75','80-81','88-90']
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006(self):
        oRule = sequential.rule_006()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'sequential')
        self.assertEqual(oRule.identifier, '006')
        dExpected = [93,94]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)



import os

import unittest
from vsg import vhdlFile

sFileLibraryName = os.path.join(os.path.dirname(__file__),'..','library','library_test_input.vhd')
oFileLibrary = vhdlFile.vhdlFile(sFileLibraryName)

oFileSignal = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','signal','signal_test_input.vhd'))

oFileProcess = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','process','process_test_input.vhd'))
oFilePort = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','port','port_test_input.vhd'))
oFileGeneric = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','generic','generic_test_input.vhd'))
oFileEntity = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','entity','entity_test_input.vhd'))
oFileConcurrent = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','concurrent','concurrent_test_input.vhd'))
oFileArchitecture = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','architecture','architecture_test_input.vhd'))
oFileArchitectureLoop = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','architecture','architecture_loop_test_input.vhd'))
oFileArchitectureFunctionLoop = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','architecture','architecture_loop_in_function_test_input.vhd'))
oFileFunction = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','function','function_test_input.vhd'))
oFileWhitespace = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','whitespace','whitespace_test_input.txt'))

class testVhdlFileMethods(unittest.TestCase):

    def test_vhdlFile_class_exists(self):
        self.assertTrue(oFileLibrary)
        self.assertEqual(oFileLibrary.filename, sFileLibraryName)

    def test_loading_of_file(self):

        # Read in test file used for all tests
        lExpected = ['']
        with open(sFileLibraryName) as oExpectedFile:
            for sLine in oExpectedFile:
                lExpected.append(sLine.rstrip())
        oExpectedFile.close()
        # Compare
        for iIndex, oLine in enumerate(oFileLibrary.lines):
            self.assertEqual(oLine.line, lExpected[iIndex])

    def test_blank_line_assignment(self):

        # Compare
        for iIndex, oLine in enumerate(oFileLibrary.lines):
            if iIndex == 1 or iIndex == 2 or iIndex == 6 or iIndex == 8 or iIndex == 11 or \
               iIndex == 12 or iIndex == 15 or iIndex == 17 or iIndex == 18 or iIndex == 19 or \
               iIndex == 22 or iIndex == 25 or iIndex == 28 or iIndex == 29 or iIndex == 31:
                self.assertTrue(oLine.isBlank)
            else:
                self.assertFalse(oLine.isBlank)

    def test_comment_assignment(self):
        lExpected = [8,50,76,83,90]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileProcess.lines):
            if oLine.isComment:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_library_assignment(self):
        lExpected = [3,7,9,13,20,21]
        # Compare
        for iIndex, oLine in enumerate(oFileLibrary.lines):
            if iIndex in lExpected:
                self.assertTrue(oLine.isLibrary)
                self.assertEqual(oLine.indentLevel, 0)
            else:
                self.assertFalse(oLine.isLibrary)

    def test_library_use_assignment(self):
        lExpected = [4,5,10,14,16,23,24,26,27,30]
        # Compare
        for iIndex, oLine in enumerate(oFileLibrary.lines):
            if iIndex in lExpected:
                self.assertTrue(oLine.isLibraryUse)
                self.assertEqual(oLine.indentLevel, 1)
            else:
                self.assertFalse(oLine.isLibraryUse)

    def test_library_use_assignment_in_port_map(self):
        '''
        This tests for an error condition in which port names that started with "use" were
        classified as a library use statement.
        '''
        lExpected = []
        # Compare
        for iIndex, oLine in enumerate(oFilePort.lines):
            if iIndex in lExpected:
                self.assertTrue(oLine.isLibraryUse)     # pragma: no cover
                self.assertEqual(oLine.indentLevel, 1)  # pragma: no cover
            else:
                self.assertFalse(oLine.isLibraryUse)


    def test_insideEntity_assignment(self):
        lExpected = [0,1,2,17,18,48,64,79,92,93,104,105,106,107,108,109,110,111,112,124,125,126,134,135,136,137,147]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileEntity.lines):
            if not oLine.insideEntity:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEntityDeclaration_assignment(self):
        lExpected = [3,19,34,49,65,80,94,113,127,138]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileEntity.lines):
            if oLine.isEntityDeclaration:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndEntityDeclaration_assignment(self):
        lExpected = [16,33,47,63,78,91,103,123,133,146]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileEntity.lines):
            if oLine.isEndEntityDeclaration:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_port_map_indent(self):
        #           [   0,   1,   2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,  17]
        lExpected = [None,None,None,0,1,2,2,1,1,2, 2, 2, 2, 2, 2, 1, 0,None]
        # Generic actual list
        lActual = []
        iMaxCheck = len(lExpected)
        for iIndex, oLine in enumerate(oFilePort.lines):
            if iIndex == iMaxCheck:
                break
            lActual.append(oLine.indentLevel)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insidePortMap_assignment(self):
        lExpected = [8,9,10,11,12,13,14,15,25,26,27,28,29,30,31,39,40,41,42,43,44,45,46,56,57,58,59,60,61,62,70,71,72,73,74,75,76,77,86,87,88,89,90,98,99,100,101,102,118,119,120,121,122,128,129,130,131,132,133,140,141,142,143,144,150,151,152,153]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFilePort.lines):
            if oLine.insidePortMap:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isPortKeyword_assignment(self):
        lExpected = [8,25,39,56,70,86,98,118,128,140,150]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFilePort.lines):
            if oLine.isPortKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndPortMap_assignment(self):
        lExpected = [15,31,46,62,77,90,102,122,133,144,153]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFilePort.lines):
            if oLine.isEndPortMap:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isPortDeclaration_assignment(self):
        lExpected = [9,10,11,12,13,14,26,27,28,29,30,31,40,41,42,43,44,45,57,58,59,60,61,62,71,72,73,74,75,76,87,88,89,99,100,101,119,120,121,129,130,131,141,142,152]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFilePort.lines):
            if oLine.isPortDeclaration:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)


    def test_insideGenericMap_assignment(self):
        lExpected = [4,5,6,7,20,21,22,23,35,36,37,38,51,52,53,54,66,67,68,69,82,83,84,85,95,96,97,114,115,116,117,139,140,141,153,154,155,156,157]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileGeneric.lines):
            if oLine.insideGenericMap:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isGenericKeyword_assignment(self):
        lExpected = [4,20,35,51,66,82,95,114,139,153]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileGeneric.lines):
            if oLine.isGenericKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndGenericMap_assignment(self):
        lExpected = [7,23,38,54,69,85,97,117,141,157]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileGeneric.lines):
            if oLine.isEndGenericMap:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isGenericDeclaration_assignment(self):
        lExpected = [5,6,21,22,36,37,52,53,67,68,83,84,96,97,116,139,140,155,156]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileGeneric.lines):
            if oLine.isGenericDeclaration:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insideArchitecture_assignment(self):
        lExpected = [3,4,5,6,7,9,10,11,12,13,14,15,16,17,18,20,21,22,23,24,26,27,28,29,30,31,33,34,35,37,38,39,40,41,42,43,44,45,47,48,49,50,51,52,53,54,55,59,60,61,62,63,64,65,66,67,68,69,70,71]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileArchitecture.lines):
            if oLine.insideArchitecture:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isArchitectureBegin_assignment(self):
        lExpected = [5,11,16,22,29,34,39,49,61]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileArchitecture.lines):
            if oLine.isArchitectureBegin:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isArchitectureKeyword_assignment(self):
        lExpected = [3,9,14,20,26,33,37,47,59]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileArchitecture.lines):
            if oLine.isArchitectureKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndArchitecture_assignment(self):
        lExpected = [7,13,18,24,31,35,45,55,71]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileArchitecture.lines):
            if oLine.isEndArchitecture:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndArchitecture_assignment_with_loop(self):
        lExpected = [11]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileArchitectureLoop.lines):
            if oLine.isEndArchitecture:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndArchitecture_assignment_with_loop_inside_function(self):
        lExpected = [21]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileArchitectureFunctionLoop.lines):
            if oLine.isEndArchitecture:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndArchitecture_function_assignment(self):
        lExpected = [122]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileFunction.lines):
            if oLine.isEndArchitecture:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isSignal_assignment(self):
        lExpected = [5,6,7,8,9,10,11,12,13,14,15,16,18,19,20,21,23]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileSignal.lines):
            if oLine.isSignal:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insideProcess_assignment(self):
        lExpected = [6,7,8,9,11,12,13,14,15,17,18,19,20,21,22,24,25,26,27,28,29,30,32,33,34,35,36,38,39,40,41,42,46,47,48,51,52,53,55,56,57,58,59,60,63,64,65,68,69,70,71,72,75,76,77,78,79,81,82,83,84,85,86,88,89,90,91,92,93,94,97,98,99,100,101,102,103]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileProcess.lines):
            if oLine.insideProcess:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isProcessBegin_assignment(self):
        lExpected = [6,13,20,28,34,40,47,52,59,64,70,77,84,92,101]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileProcess.lines):
            if oLine.isProcessBegin:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isProcessKeyword_assignment(self):
        lExpected = [6,11,17,24,32,38,46,51,55,63,68,75,81,88,97]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileProcess.lines):
            if oLine.isProcessKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isProcessLabel_assignment(self):
        lExpected = [46,63,68,75,81,88,97]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileProcess.lines):
            if oLine.isProcessLabel:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndProcess_assignment(self):
        lExpected = [9,15,22,30,36,42,48,53,60,65,72,79,86,94,103]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileProcess.lines):
            if oLine.isEndProcess:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insideSensitivityList_assignment(self):
        lExpected = [6,11,12,17,18,19,24,25,26,27,32,33,38,39,46,51,55,56,57,63,68,75,81,88,97]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileProcess.lines):
            if oLine.insideSensitivityList:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isSensitivityListBegin_assignment(self):
        lExpected = [6,11,17,24,32,38,46,51,55,63,68,75,81,88,97]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileProcess.lines):
            if oLine.isSensitivityListBegin:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isSensitivityListEnd_assignment(self):
        lExpected = [6,12,19,27,33,39,46,51,57,63,68,75,81,88,97]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileProcess.lines):
            if oLine.isSensitivityListEnd:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insideConcurrent_assignment(self):
        lExpected = [6,7,8,9,10,11,23,24,26,27,28,29,30,32,33,34,35,36,38,39,40,41,42,44,45,46,48]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileConcurrent.lines):
            if oLine.insideConcurrent:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isConcurrentBegin_assignment(self):
        lExpected = [6,7,8,9,11,23,24,26,32,33,34,35,38,39,42,44,45,48]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileConcurrent.lines):
            if oLine.isConcurrentBegin:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndConcurrent_assignment(self):
        lExpected = [6,7,8,10,11,23,24,30,32,33,34,36,38,41,42,44,46,48]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileConcurrent.lines):
            if oLine.isEndConcurrent:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_hasEntity_assignment(self):
        self.assertFalse(oFileConcurrent.hasEntity)
        self.assertTrue(oFilePort.hasEntity)
        self.assertTrue(oFileEntity.hasEntity)

    def test_hasArchitecture_assignment(self):
        self.assertFalse(oFileWhitespace.hasArchitecture)
        self.assertTrue(oFileConcurrent.hasArchitecture)
        self.assertTrue(oFileProcess.hasArchitecture)



import os

import unittest
from vsg import vhdlFile

oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','function','function_test_input.vhd'))
oFileMultiple = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','function','function_multiple_parameters_test_input.vhd'))

class testVhdlFileFunctionAssignments(unittest.TestCase):

    def test_isFunctionKeyword(self):
        lExpected = [4,16,21,28,36,47,54,63,70,78,87,97,110,126,128]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isFunctionKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isFunctionBegin(self):
        lExpected = [5,17,22,31,37,50,57,66,74,83,93,104,115]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isFunctionBegin:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isFunctionEnd(self):
        lExpected = [13,19,24,33,45,52,59,68,76,85,95,106,117,126,130]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isFunctionEnd:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_insideFunction(self):
        lExpected = [4,5,6,7,8,9,10,11,12,13,16,17,18,19,21,22,23,24,28,29,30,31,32,33,36,37,38,39,40,41,42,43,44,45,47,48,49,50,51,52,54,55,56,57,58,59,63,64,65,66,67,68,70,71,72,73,74,75,76,78,79,80,81,82,83,84,85,87,88,89,90,91,92,93,94,95,97,98,99,100,101,102,103,104,105,106,110,111,112,113,114,115,116,117,126,128,129,130]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.insideFunction:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isFunctionReturn(self):
        lExpected = [8,10,18,23,51,58,67,75,84,94,105,116]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isFunctionReturn:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)


    def test_FunctionIndent(self):
        #           [   0,   1,2,   3,4,5,   6,7,8,9,10,11,  12,13,  14]
        lExpected = [None,None,0,None,1,1,None,2,3,2, 3, 2,None, 1,None]
        # Generic actual list
        lActual = []
        iMaxCheck = len(lExpected)
        for iIndex, oLine in enumerate(oFile.lines):
            if iIndex == iMaxCheck:
                break
            lActual.append(oLine.indentLevel)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isFunctionParameter(self):
        lExpected = [4,16,21,28,29,36,47,54,63,64,65,70,71,72,78,79,80,87,88,89,97,98,99,110,111,112,126,128,129,130]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isFunctionParameter:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isFunctionParameterMultiple(self):
        lExpected = [4,5,6,7,19,20,21,22,23]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileMultiple.lines):
            if oLine.isFunctionParameter:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_is_not_constant(self):
        lExpected = []
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileMultiple.lines):
            if oLine.isConstant:
                lActual.append(iIndex)  # pragma: no cover
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_is_not_signal(self):
        lExpected = []
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFileMultiple.lines):
            if oLine.isSignal:
                lActual.append(iIndex)  # pragma: no cover
        # Compare
        self.assertEqual(lActual, lExpected)



import os

import unittest
from vsg import vhdlFile

oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','for_loop','for_loop_test_input.vhd'))

class testVhdlFileForLoopAssignments(unittest.TestCase):


    def test_isForLoopKeyword(self):
        lExpected = [9,19,21,26]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isForLoopKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isForLoopEnd(self):
        lExpected = [11,23,24,28]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isForLoopEnd:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_ForLoopIndent(self):
        #           [   0,   1,2,   3,4,   5,6,7,   8,9,10,11,  12,13,   14]
        lExpected = [None,None,0,None,0,None,1,1,None,2, 3, 2,None, 1, None]
        # Generic actual list
        lActual = []
        iMaxCheck = len(lExpected)
        for iIndex, oLine in enumerate(oFile.lines):
            if iIndex == iMaxCheck:
                break
            lActual.append(oLine.indentLevel)
        # Compare
        self.assertEqual(lActual, lExpected)



import os

import unittest
from vsg import vhdlFile

oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','package','package_test_input.vhd'))

class testVhdlFilePackageMethods(unittest.TestCase):


    def test_insidePackage_assignment(self):
        lExpected = [2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,47,48,49,50,51,52,53,54,55,56,57,58,60,61,62,63,64,65,66,67,68,69,70,71,72,73]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.insidePackage:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isPackageKeyword_assignment(self):
        lExpected = [2,18,32,47,60]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isPackageKeyword:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_isEndPackage_assignment(self):
        lExpected = [15,31,45,58,73]
        # Generic actual list
        lActual = []
        for iIndex, oLine in enumerate(oFile.lines):
            if oLine.isPackageEnd:
                lActual.append(iIndex)
        # Compare
        self.assertEqual(lActual, lExpected)

    def test_packageIndent_assignment(self):
#        lExpected = [2,    ,4,5,6,7,8,9,10,11,12,13,  14,15,18,  19,20,21,22,23,24,25,26,27,28,29,  30,31,32,  33,34,35,36,37,38,39,40,41,42,43,  44,45,47,48,49,50,51,52,53,54,55,56,57,58,60,  61,62,63,64,65,66,67,68,69,70,71,  72,73]
        lExpected =  [0,None,1,2,3,2,2,3, 3, 3, 2, 1,None, 0, 0,None, 1, 2, 3, 2, 2, 3, 3, 3, 2, 1,None, 0, 0,None, 1, 2, 3, 2, 2, 3, 3, 3, 2, 1,None, 0, 0, 1, 2, 3, 2, 2, 3, 3, 3, 2, 1, 0, 0,None, 1, 2, 3, 2, 2, 3, 3, 3, 2, 1,None, 0]
        # Generic actual list
        lActual = []
        for oLine in oFile.lines:
            if oLine.insidePackage:
                lActual.append(oLine.indentLevel)
        # Compare
        self.assertEqual(lActual, lExpected)



import os

import unittest

from vsg.rules import package
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','package','package_test_input.vhd'))

class testRulePackageMethods(unittest.TestCase):

    def test_rule_001(self):
        oRule = package.rule_001()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '001')

        dExpected = [32]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_002(self):
        oRule = package.rule_002()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '002')

        dExpected = [32,47]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_003(self):
        oRule = package.rule_003()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '003')

        dExpected = [32]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_004(self):
        oRule = package.rule_004()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '004')

        dExpected = [18]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_005(self):
        oRule = package.rule_005()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '005')

        dExpected = [18,60]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_006(self):
        oRule = package.rule_006()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '006')

        dExpected = [31,45]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_007(self):
        oRule = package.rule_007()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '007')
        dExpected = [58]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_008(self):
        oRule = package.rule_008()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '008')
        dExpected = [31]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_009(self):
        oRule = package.rule_009()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '009')
        dExpected = [15,31,58,73]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_010(self):
        oRule = package.rule_010()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '010')
        dExpected = [47]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_011(self):
        oRule = package.rule_011()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '011')
        dExpected = [47, 60]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_012(self):
        oRule = package.rule_012()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '012')
        dExpected = [58]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_013(self):
        oRule = package.rule_013()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '013')
        dExpected = [32]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_014(self):
        oRule = package.rule_014()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '014')
        dExpected = [73]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_rule_015(self):
        oRule = package.rule_015()
        self.assertTrue(oRule)
        self.assertEqual(oRule.name, 'package')
        self.assertEqual(oRule.identifier, '015')

        dExpected = [45]
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)




import os

import unittest

from vsg.rules import while_loop
from vsg import vhdlFile

# Read in test file used for all tests
oFile = vhdlFile.vhdlFile(os.path.join(os.path.dirname(__file__),'..','while_loop','while_loop_test_input.vhd'))

class testFixRuleWhileLoopMethods(unittest.TestCase):

    def test_fix_rule_001(self):
        oRule = while_loop.rule_001()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)

    def test_fix_rule_002(self):
        oRule = while_loop.rule_002()
        dExpected = []
        oRule.fix(oFile)
        oRule.analyze(oFile)
        self.assertEqual(oRule.violations, dExpected)
